@@ -52,7 +52,9 @@ KEduVocDocument::ErrorCode KEduVocCsvReader::read(KEduVocDocument & doc )
     QString separator = m_doc->csvDelimiter();
 
     QTextStream inputStream( m_inputFile );
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     inputStream.setCodec( "UTF-8" );
+#endif
     inputStream.setAutoDetectUnicode( true );
     inputStream.seek( 0 );
 
